@@ -27,7 +27,7 @@ LogistikPoly <- function(data, member, member.type = "group", match = "score",
       data2 <- data
       items_for_score <- setdiff(anchor, item)
       if (length(items_for_score) == 0) {
-        SCORES <- rep(0, nrow(data))  # Aucun autre item
+        SCORES <- rep(0, nrow(data))
       } else {
         SCORES <- rowSums(data[, items_for_score, drop = FALSE], na.rm = TRUE)
       }
@@ -39,25 +39,30 @@ LogistikPoly <- function(data, member, member.type = "group", match = "score",
 
     ITEM <- data[, item]
 
-    m0 <- switch(type,
+    # ----- modèles complets / réduits -----
+    m0 <- switch(
+      type,
       both  = vglm(ITEM ~ SCORES * GROUP, family = propodds, data = data2, model = TRUE),
-      udif  = vglm(ITEM ~ SCORES + GROUP, family = propodds, data = data2, model = TRUE),
-      nudif = vglm(ITEM ~ SCORES * GROUP, family = propodds, data = data2, model = TRUE)
+      udif  = vglm(ITEM ~ SCORES + GROUP,   family = propodds, data = data2, model = TRUE),
+      nudif = vglm(ITEM ~ SCORES * GROUP,   family = propodds, data = data2, model = TRUE)
     )
 
-    m1 <- switch(type,
-      both  = vglm(ITEM ~ SCORES, family = propodds, data = data2, model = TRUE),
-      udif  = vglm(ITEM ~ SCORES, family = propodds, data = data2, model = TRUE),
-      nudif = vglm(ITEM ~ SCORES + GROUP, family = propodds, data = data2, model = TRUE)
+    m1 <- switch(
+      type,
+      both  = vglm(ITEM ~ SCORES,          family = propodds, data = data2, model = TRUE),
+      udif  = vglm(ITEM ~ SCORES,          family = propodds, data = data2, model = TRUE),
+      nudif = vglm(ITEM ~ SCORES + GROUP,  family = propodds, data = data2, model = TRUE)
     )
 
+    # ----- statistique DIF -----
     if (criterion == "LRT") {
-      dev[item] <- VGAM::deviance(m1) - VGAM::deviance(m0)
+      dev[item] <- deviance(m1) - deviance(m0)
 
     } else if (criterion == "Wald") {
       coef_m0 <- stats::coef(m0)
       vcov_m0 <- stats::vcov(m0)
-      idx <- switch(type,
+      idx <- switch(
+        type,
         udif  = length(coef_m0),
         nudif = length(coef_m0),
         both  = (length(coef_m0) - 1):length(coef_m0)
@@ -70,14 +75,14 @@ LogistikPoly <- function(data, member, member.type = "group", match = "score",
       stop("'criterion' must be either 'LRT' or 'Wald'")
     }
 
-    R2full[item] <- PseudoR2(m0, which = "McKelveyZavoina")
+    R2full[item]   <- PseudoR2(m0, which = "McKelveyZavoina")
     R2simple[item] <- PseudoR2(m1, which = "McKelveyZavoina")
-    deltaR[item] <- R2full[item] - R2simple[item]
+    deltaR[item]   <- R2full[item] - R2simple[item]
 
-    mFull[item, 1:length(stats::coef(m0))] <- stats::coef(m0)
+    mFull[item, 1:length(stats::coef(m0))]   <- stats::coef(m0)
     mSimple[item, 1:length(stats::coef(m1))] <- stats::coef(m1)
-    seFull[item, 1:length(stats::coef(m0))] <- sqrt(diag(stats::vcov(m0)))
-    seSimple[item, 1:length(stats::coef(m1))] <- sqrt(diag(stats::vcov(m1)))
+    seFull[item, 1:length(stats::coef(m0))]  <- sqrt(diag(stats::vcov(m0)))
+    seSimple[item, 1:length(stats::coef(m1))]<- sqrt(diag(stats::vcov(m1)))
 
     if (all.cov) {
       cov.matM0[[item]] <- stats::vcov(m0)
@@ -89,23 +94,22 @@ LogistikPoly <- function(data, member, member.type = "group", match = "score",
   colnames(mFull) <- colnames(mSimple) <- colnames(seFull) <- colnames(seSimple) <- col_labels
 
   list(
-    stat = dev,
-    R2M0 = R2full,
-    R2M1 = R2simple,
-    deltaR2 = deltaR,
-    parM0 = mFull,
-    parM1 = mSimple,
-    seM0 = seFull,
-    seM1 = seSimple,
-    cov.M0 = cov.matM0,
-    cov.M1 = cov.matM1,
-    criterion = criterion,
+    stat     = dev,
+    R2M0     = R2full,
+    R2M1     = R2simple,
+    deltaR2  = deltaR,
+    parM0    = mFull,
+    parM1    = mSimple,
+    seM0     = seFull,
+    seM1     = seSimple,
+    cov.M0   = cov.matM0,
+    cov.M1   = cov.matM1,
+    criterion= criterion,
     member.type = member.type,
-    match = match[1]
+    match    = match[1]
   )
 }
 
-
 ##########################################################################
 
 #' @importFrom stats qchisq pchisq p.adjust
